@@ -19,7 +19,7 @@ package Pod::Loom::Template::Identity;
 
 use 5.008;
 our $VERSION = '0.03';
-# This file is part of Pod-Loom 0.03 (March 6, 2010)
+# This file is part of Pod-Loom 0.04 (December 11, 2010)
 
 use strict;
 use warnings;
@@ -53,8 +53,8 @@ Pod::Loom::Template::Identity - Do-nothing template for Pod::Loom
 =head1 VERSION
 
 This document describes version 0.03 of
-Pod::Loom::Template::Identity, released March 6, 2010
-as part of Pod-Loom version 0.03.
+Pod::Loom::Template::Identity, released December 11, 2010
+as part of Pod-Loom version 0.04.
 
 =head1 DESCRIPTION
 
@@ -92,10 +92,10 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  C<< <perlATcjmweb.net> >>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-C<< <bug-Pod-LoomATrt.cpan.org> >>,
+S<C<< <bug-Pod-Loom AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Pod-Loom>
 
